==> vue-infinite-scroll-0.0.7.tgz: package/lib/index.js <==
'use strict';

var Vue = require('vue');

var throttle = function throttle(fn, delay) {
  var now, lastExec, timer, context, args;

  var execute = function execute() {
    fn.apply(context, args);
    lastExec = now;
  };

  return function () {
    context = this;
    args = arguments;

    now = Date.now();

    if (timer) {
      clearTimeout(timer);
      timer = null;
    }

    if (!lastExec) {
      execute();
    } else {
      var diff = delay - (now - lastExec);
      if (diff < 0) {
        execute();
      } else {
        timer = setTimeout(function () {
          execute();
        }, diff);
      }
    }
  };
};

var getScrollTop = function getScrollTop(element) {
  if (element === window) {
    return Math.max(window.pageYOffset || 0, document.documentElement.scrollTop);
  }

  return element.scrollTop;
};

var getComputedStyle = document.defaultView.getComputedStyle;

var getScrollEventTarget = function getScrollEventTarget(element) {
  var currentNode = element;
  while (currentNode && currentNode.tagName !== 'HTML' && currentNode.nodeType === 1) {
    var overflowY = getComputedStyle(currentNode)['overflowY'];
    if (overflowY === 'scroll' || overflowY === 'auto') {
      return currentNode;
    }
    currentNode = currentNode.parentNode;
  }
  return null;
};

var getVisibleHeight = function getVisibleHeight(element) {
  if (element === window) {
    return document.documentElement.clientHeight;
  }

  return element.clientHeight;
};

var getElementTop = function getElementTop(element) {
  return element.getBoundingClientRect().top + getScrollTop(window);
};

var isAttached = function isAttached(element) {
  var currentNode = element.parentNode;
  while (currentNode) {
    if (currentNode.tagName === 'HTML') {
      return true;
    }
    if (currentNode.nodeType === 11) {
      return false;
    }
    currentNode = currentNode.parentNode;
  }
  return false;
};

Vue.directive('infiniteScroll', {
  doBind: function doBind() {
    var element = this.el;

    var disabledExpr = element.getAttribute('infinite-scroll-disabled');
    var disabled = false;
    if (disabledExpr) {
      this.vm.$watch(disabledExpr, function (value) {
        disabled = value;
      });
      disabled = !!this.vm.$get(disabledExpr);
    }

    var distanceExpr = element.getAttribute('infinite-scroll-distance');
    var distance = 1;
    if (distanceExpr) {
      distance = Number(this.vm.$get(distanceExpr));
      if (isNaN(distance)) {
        distance = 1;
      }
    }

    var directive = this;
    var executeExpr = directive.expression;

    var scrollEventTarget = this.scrollEventTarget = getScrollEventTarget(element) || window;

    this.scrollListener = throttle(function () {
      if (disabled) return;
      var viewportScrollTop = getScrollTop(scrollEventTarget);
      var viewportBottom = viewportScrollTop + getVisibleHeight(scrollEventTarget);

      var shouldTrigger = false;

      if (scrollEventTarget !== element) {
        var elementRect = element.getBoundingClientRect();
        var elementBottom = getElementTop(element) - getElementTop(scrollEventTarget) + elementRect.bottom + viewportScrollTop;

        shouldTrigger = viewportBottom + distance > elementBottom;
      } else {
        shouldTrigger = scrollEventTarget.scrollHeight - viewportBottom < distance;
      }

      if (shouldTrigger && executeExpr) {
        directive.vm.$get(executeExpr);
      }
    }, 200);

    scrollEventTarget.addEventListener('scroll', this.scrollListener);
  },

  bind: function bind() {
    var directive = this;
    var element = this.el;

    directive.vm.$on('hook:ready', function () {
      if (isAttached(element)) {
        directive.doBind();
      }
    });

    this.bindTryCount = 0;

    directive.timer = setTimeout(function () {
      if (directive.bindTryCount > 10) return;
      directive.bindTryCount++;
      if (isAttached(element)) {
        directive.doBind();
      } else {
        directive.timer = setTimeout(arguments.callee, 50);
      }
    }, 50);
  },

  unbind: function unbind() {
    this.scrollEventTarget.removeEventListener('scroll', this.scrollListener);
  }
});

==> vue-infinite-scroll-0.0.8.tgz: package/lib/index.js <==
'use strict';

var Vue = require('vue');

var throttle = function throttle(fn, delay) {
  var now, lastExec, timer, context, args;

  var execute = function execute() {
    fn.apply(context, args);
    lastExec = now;
  };

  return function () {
    context = this;
    args = arguments;

    now = Date.now();

    if (timer) {
      clearTimeout(timer);
      timer = null;
    }

    if (!lastExec) {
      execute();
    } else {
      var diff = delay - (now - lastExec);
      if (diff < 0) {
        execute();
      } else {
        timer = setTimeout(function () {
          execute();
        }, diff);
      }
    }
  };
};

var getScrollTop = function getScrollTop(element) {
  if (element === window) {
    return Math.max(window.pageYOffset || 0, document.documentElement.scrollTop);
  }

  return element.scrollTop;
};

var getComputedStyle = document.defaultView.getComputedStyle;

var getScrollEventTarget = function getScrollEventTarget(element) {
  var currentNode = element;
  while (currentNode && currentNode.tagName !== 'HTML' && currentNode.nodeType === 1) {
    var overflowY = getComputedStyle(currentNode)['overflowY'];
    if (overflowY === 'scroll' || overflowY === 'auto') {
      return currentNode;
    }
    currentNode = currentNode.parentNode;
  }
  return null;
};

var getVisibleHeight = function getVisibleHeight(element) {
  if (element === window) {
    return document.documentElement.clientHeight;
  }

  return element.clientHeight;
};

var getElementTop = function getElementTop(element) {
  return element.getBoundingClientRect().top + getScrollTop(window);
};

var isAttached = function isAttached(element) {
  var currentNode = element.parentNode;
  while (currentNode) {
    if (currentNode.tagName === 'HTML') {
      return true;
    }
    if (currentNode.nodeType === 11) {
      return false;
    }
    currentNode = currentNode.parentNode;
  }
  return false;
};

Vue.directive('infiniteScroll', {
  doBind: function doBind() {
    if (this.binded) return;
    this.binded = true;

    var directive = this;
    var element = directive.el;

    directive.scrollEventTarget = getScrollEventTarget(element) || window;
    directive.scrollListener = throttle(directive.doCheck.bind(directive), 200);
    directive.scrollEventTarget.addEventListener('scroll', directive.scrollListener);

    var disabledExpr = element.getAttribute('infinite-scroll-disabled');
    var disabled = false;

    if (disabledExpr) {
      this.vm.$watch(disabledExpr, function (value) {
        directive.disabled = value;
      });
      disabled = !!directive.vm.$get(disabledExpr);
    }
    directive.disabled = disabled;

    var distanceExpr = element.getAttribute('infinite-scroll-distance');
    var distance = 0;
    if (distanceExpr) {
      distance = Number(directive.vm.$get(distanceExpr));
      if (isNaN(distance)) {
        distance = 0;
      }
    }
    directive.distance = distance;

    var immediateCheckExpr = element.getAttribute('infinite-scroll-immediate-check');
    var immediateCheck = true;
    if (immediateCheckExpr) {
      immediateCheck = !!directive.vm.$get(immediateCheckExpr);
    }

    if (immediateCheck) {
      directive.doCheck();
    }

    var eventName = element.getAttribute('infinite-scroll-listen-for-event');
    if (eventName) {
      if (eventName) {
        directive.vm.$on(eventName, function () {
          directive.doCheck();
        });
      }
    }
  },

  doCheck: function doCheck() {
    var scrollEventTarget = this.scrollEventTarget;
    var element = this.el;
    var distance = this.distance;

    if (this.disabled) return;
    var viewportScrollTop = getScrollTop(scrollEventTarget);
    var viewportBottom = viewportScrollTop + getVisibleHeight(scrollEventTarget);

    var shouldTrigger = false;

    if (scrollEventTarget !== element) {
      var elementBottom = getElementTop(element) - getElementTop(scrollEventTarget) + element.offsetHeight + viewportScrollTop;

      shouldTrigger = viewportBottom + distance >= elementBottom;
    } else {
      shouldTrigger = scrollEventTarget.scrollHeight - viewportBottom <= distance;
    }

    if (shouldTrigger && this.expression) {
      this.vm.$get(this.expression);
    }
  },

  bind: function bind() {
    var directive = this;
    var element = this.el;

    directive.vm.$on('hook:ready', function () {
      if (isAttached(element)) {
        directive.doBind();
      }
    });

    this.bindTryCount = 0;

    directive.timer = setTimeout(function () {
      if (directive.bindTryCount > 10) return;
      directive.bindTryCount++;
      if (isAttached(element)) {
        directive.doBind();
      } else {
        directive.timer = setTimeout(arguments.callee, 50);
      }
    }, 50);
  },

  unbind: function unbind() {
    this.scrollEventTarget.removeEventListener('scroll', this.scrollListener);
  }
});
